﻿// --------------------------------------------------------------------------------------
//
// TresorCodeCS.cs                                                Ulrich Müller  29.06.07
//                                                                PCS1700 C# 2005 Express
// Profi Computing 1991 Experimentierbuch : Tresorbetrieb über Codetasten
// Codeeingabe : Abgefragt werden alle Codetasten auf einmal auf ungleich null
//               der festgestellte Wert wird mit der akt. Zweierpotenz multipliziert
//               und auf Codezahl addiert. z.B. ergibt die Eingabe 132 so den Wert 17.
// Tresor wieder schliessen über I4.
// Basis ist die Assembly FishFace2005.DLL
//
// --------------------------------------------------------------------------------------

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using FishFace40;

namespace BeispieleFishFace {
  public partial class TresorCodeCS : Form {
    const Out mTresor       = Out.M1;
    const Inp eCodeTaste1   = Inp.I1;
    const Inp eCodeTaste2   = Inp.I2;
    const Inp eCodeTaste3   = Inp.I3;
    const Inp eCodeTaste4   = Inp.I4;
    const Inp eTresorSchliessen = Inp.I4;
    const Inp eTresorOffen  = Inp.I5;
    const Inp eTresorZu     = Inp.I6;
    const Dir dSchliessen   = Dir.Right;
    const Dir dOeffnen      = Dir.Left;

    FishFace ft = new FishFace();

    private void Action() {
      int CodeZahl;
      int IStat;
      do {
        lblStatus.Text = "Tresor schliesst";
        ft.SetMotor(mTresor, dSchliessen);
        ft.WaitForInput(eTresorZu);
        ft.SetMotor(mTresor, Dir.Off);

        lblStatus.Text = "Bitte Code eingeben";
        CodeZahl = 0;
        for (int i = 1; i < 16; i *= 2) {
          IStat = 0;
          while ((IStat == 0) && !ft.NotHalt) {IStat = ft.GetInputs() & 0xF; ft.Pause(44);}
          CodeZahl += IStat * i;
          while ((IStat != 0) && !ft.NotHalt) {IStat = ft.GetInputs() & 0xF; ft.Pause(44);}
        }
        if (CodeZahl == 32) {
          lblStatus.Text = "Tresor öffnet";
          ft.SetMotor(mTresor, dOeffnen);
          ft.WaitForInput(eTresorOffen);
          ft.SetMotor(mTresor, Dir.Off);

          lblStatus.Text = "Tresor schliessen : I4";
          ft.WaitForInput(eTresorSchliessen);
        }
        else {
          lblStatus.Text = "Das war wohl nichts!";
          ft.Pause(2345);
        }
      } while (!ft.Finish());
    }

    #region --- Programm-Kontrolle ---
    public TresorCodeCS() {
      InitializeComponent();
    }

    private void cmdAction_Click(object sender, EventArgs e) {
      // --- Open erstes ROBO an USB oder Intelligent Interface an COM
      //     während des Ablaufs von Action() gesperrt ---------------
      try {
        if (cboPortName.SelectedIndex == 0)
          ft.OpenInterface(IFTypen.ftROBO_first_USB, 0);
        else ft.OpenInterface(IFTypen.ftIntelligent_IF, cboPortName.SelectedIndex, 5);
        cmdAction.Enabled = false;
        cmdEnde.Text = "&HALT";
        lblStatus.Text = "--- Bei der Arbeit ---";
        lblHinweis.Text = "--- Ende : HALT-Button oder ESC-Taste ---";

        Action();        // --- Haupt-Routine der Anwendung

        ft.ClearMotors();
      }
      catch (FishFaceException eft) {
        MessageBox.Show(eft.Message, this.Text,
          MessageBoxButtons.OK, MessageBoxIcon.Stop);
      }
      finally {
        ft.CloseInterface();
        cmdAction.Enabled = true;
        cmdEnde.Text = "&ENDE";
        lblStatus.Text = "--- Auf ein Neues ---";
        lblHinweis.Text = "Nochmal : ACTION, sonst ENDE oder ESC-Taste";
        cmdAction.Focus();
      }
    }

    private void cmdEnde_Click(object sender, EventArgs e) {
      // --- Programmende nur, wenn Action nicht läuft ---
      if (cmdEnde.Text == "&HALT") ft.NotHalt = true; else this.Close();
    }

    private void formLoad(object sender, EventArgs e) {
      // --- Default-Interface : Erstes ROBO Interface an USB ----
      cboPortName.SelectedIndex = 0;
    }

    private void formClosing(object sender, FormClosingEventArgs e) {
      // --- Wenn Action läuft, wird ein Programmabbruch über (x) unterbunden ------
      if (cmdEnde.Text == "&HALT") e.Cancel = true;
    }
    #endregion
  }
}